@@ -8,7 +8,7 @@ use Mojo::URL;
 use Mojo::Base 'Mojolicious::Plugin';
 
 # ABSTRACT: Plugin for clustericious to use PlugAuth.
-our $VERSION = '1.16'; # VERSION
+our $VERSION = '1.17'; # VERSION
 
 
 has 'config_url';
@@ -47,7 +47,7 @@ sub authenticate {
 
     # VIP treatment for some hosts
     my $ip = $c->tx->remote_address;
-    $c->auth_ua->get("$config_url/host/$ip/trusted", sub {
+    $c->ua->get("$config_url/host/$ip/trusted", sub {
         my $ua = shift;
     
         do {
@@ -126,9 +126,9 @@ sub authorize {
 
     my $url = Mojo::URL->new( join '/', $self->config_url, "authz/user", $user, $action, $resource );
 
-    my $tx = $c->auth_ua->build_tx(HEAD => $url);
+    my $tx = $c->ua->build_tx(HEAD => $url);
     
-    $c->auth_ua->start($tx, sub {
+    $c->ua->start($tx, sub {
         my($ua, $tx) = @_;
         
         my $code = $tx->res->code;
@@ -163,7 +163,7 @@ Clustericious::Plugin::PlugAuth - Plugin for clustericious to use PlugAuth.
 
 =head1 VERSION
 
-version 1.16
+version 1.17
 
 =head1 SYNOPSIS
 
